summaryrefslogtreecommitdiff
path: root/apt-pkg/cdrom.h
diff options
context:
space:
mode:
Diffstat (limited to 'apt-pkg/cdrom.h')
-rw-r--r--apt-pkg/cdrom.h8
1 files changed, 7 insertions, 1 deletions
diff --git a/apt-pkg/cdrom.h b/apt-pkg/cdrom.h
index 14ca1d810..032fae755 100644
--- a/apt-pkg/cdrom.h
+++ b/apt-pkg/cdrom.h
@@ -68,7 +68,7 @@ class pkgCdrom /*{{{*/
/*}}}*/
// class that uses libudev to find cdrom devices dynamically
struct CdromDevice /*{{{*/
{
string DeviceName;
@@ -92,6 +92,7 @@ class pkgUdevCdromDevices /*{{{*/
struct udev_enumerate *(*udev_enumerate_new) (struct udev *udev);
struct udev_list_entry *(*udev_list_entry_get_next)(struct udev_list_entry *list_entry);
const char* (*udev_device_get_property_value)(struct udev_device *udev_device, const char *key);
+ int (*udev_enumerate_add_match_sysattr)(struct udev_enumerate *udev_enumerate, const char *property, const char *value);
// end libudev dlopen
public:
@@ -100,7 +101,12 @@ class pkgUdevCdromDevices /*{{{*/
// try to open
bool Dlopen();
+
+ // this is the new interface
+ vector<CdromDevice> ScanForRemovable(bool CdromOnly);
+ // FIXME: compat with the old interface/API/ABI only
vector<CdromDevice> Scan();
+
};
/*}}}*/
@@ -68,7 +68,7 @@ class pkgCdrom /*{{{*/
/*}}}*/
-// class that uses libudev to find cdrom devices dynamically
+// class that uses libudev to find cdrom/removable devices dynamically
struct CdromDevice /*{{{*/
{